==> tecfy_core_package-0.1.9.tar.gz: lib/models/project/connection.model.dart <==
part of tecfy_core_client_package;

class Connection {
  String id;
  bool isCloud;
  String name;
  String version;
  DateTime lastActive;
  Color color;
  String get colorString => color?.toHexString() ?? Colors.black.toHexString();
  set colorString(String s) => color = (s?.toColor(Colors.black) ?? Colors.black);
  String server;
  bool isHTTPS;
  ConnectionStatus status;
  bool active;
  int sortId;
  String errorMessage;
  Connection(
      {this.id,
      this.sortId = 1,
      this.isCloud = true,
      this.name,
      this.color = Colors.black,
      this.server,
      this.status = ConnectionStatus.unknown,
      this.active = true,
      this.isHTTPS = false});

  String get apiUrl => '${isHTTPS ? 'https' : 'http'}://$server/api/';
  String get wsURL => 'ws://$server/ws';

  Connection.fromJson(Map row) {
    id = row['id'];
    sortId = row['sortId'] ?? 1;
    name = row['name'];
    isCloud = row['isCloud'] ?? true;
    version = row['version'];
    lastActive = (row['lastActive'] == null || row['lastActive'] == 0)
        ? null
        : DateTime.fromMillisecondsSinceEpoch(row['lastActive'],isUtc:true);
    colorString = row['colorString'];
    server = row['server'];
    isHTTPS = row['isHTTPS'];
    active = row['active'] ?? true;
  }

  toJson() {
    return {
      'id': id ?? Uuid().v4().replaceAll('-', ''),
      'name': name,
      'sortId': sortId,
      'isCloud': isCloud,
      'version': version,
      'lastActive': lastActive?.millisecondsSinceEpoch ?? 0,
      'colorString': colorString,
      'server': server,
      'isHTTPS': isHTTPS,
      'active': active ?? true
    };
  }
}

enum ConnectionStatus {
  unknown,
  connected,
  disconnected,
}

enum ConnectionType {
  local,
  cloud,
}

==> tecfy_core_package-0.1.36.tar.gz: lib/models/project/connection.model.dart <==
part of tecfy_core_client_package;

class Connection {
  String id;
  bool isCloud;
  String name;
  String version;
  DateTime lastActive;
  Color color;
  String get colorString => color?.toHexString() ?? Colors.black.toHexString();
  set colorString(String s) => color = (s?.toColor(Colors.black) ?? Colors.black);
  String server;
  bool isHTTPS;
  ConnectionStatus status;
  bool active;
  int sortId;
  String errorMessage;
  Connection(
      {this.id,
      this.sortId = 1,
      this.isCloud = true,
      this.name,
      this.color = Colors.black,
      this.server,
      this.status = ConnectionStatus.unknown,
      this.active = true,
      this.isHTTPS = false}){
         if (id == null) id = Uuid().v4().replaceAll('-', '');
      }

  String get apiUrl => '${isHTTPS ? 'https' : 'http'}://$server/api/';
  String get wsURL => 'ws://$server/ws';

  Connection.fromJson(Map row) {
    id = row['id'];
    sortId = row['sortId'] ?? 1;
    name = row['name'];
    isCloud = row['isCloud'] ?? true;
    version = row['version'];
    lastActive = (row['lastActive'] == null || row['lastActive'] == 0)
        ? null
        : DateTime.fromMillisecondsSinceEpoch(row['lastActive'],isUtc:true);
    colorString = row['colorString'];
    server = row['server'];
    isHTTPS = row['isHTTPS'];
    active = row['active'] ?? true;
  }

  toJson() {
    return {
      'id': id ?? Uuid().v4().replaceAll('-', ''),
      'name': name,
      'sortId': sortId,
      'isCloud': isCloud,
      'version': version,
      'lastActive': lastActive?.millisecondsSinceEpoch ?? 0,
      'colorString': colorString,
      'server': server,
      'isHTTPS': isHTTPS,
      'active': active ?? true
    };
  }
}

enum ConnectionStatus {
  unknown,
  connected,
  disconnected,
}

enum ConnectionType {
  local,
  cloud,
}
